RequestedReviewAudience

Enum RequestedReviewAudience 

pub enum RequestedReviewAudience {
    Personal,
    Group,
}
Review audience that caused one PR or MR to require the current user’s attention.

Variants



Personal

The current user was directly requested as a reviewer.



Group

A group or team containing the current user was requested as reviewer.