ReviewRequestState

Enum ReviewRequestState 

pub enum ReviewRequestState {
    Open,
    Merged,
    Closed,
}
Normalized remote lifecycle state for one linked review request.

Variants



Open

The linked review request is still open.



Merged

The linked review request was merged upstream.



Closed

The linked review request was closed without merge.

Implementations

Source

impl ReviewRequestState

pub fn as_str(self) -> &'static str

Returns the persisted string representation for this remote state.