pub struct ReviewComment {
pub author: String,
pub authored_by_current_user: bool,
pub body: String,
}Expand description
One inline review comment emitted by a reviewer on a forge review thread.
Fields
Forge author login or display name.
Whether the forge reports that the authenticated user authored this comment.
body: StringMarkdown body as authored on the forge.
Implementations
Sourceimpl ReviewComment
impl ReviewComment
Sourcepub fn is_agentty_reply(&self) -> bool
pub fn is_agentty_reply(&self) -> bool
Returns whether this comment ends with an Agentty reply marker.