pub struct ReviewRequestMetadataFieldUpdate {
pub current: String,
pub desired: String,
}Expand description
One review-request field update guarded by the remote value used during semantic reconciliation.
Fields
current: StringRemote value read before semantic reconciliation.
desired: StringReconciled value to publish if the remote field is still unchanged.