UpdateReviewRequestInput

Struct UpdateReviewRequestInput 

pub struct UpdateReviewRequestInput {
    pub body: Option<String>,
    pub title: String,
}
Input required to keep an existing review request aligned with the latest session commit message.

Fields

body: Option<String>

Optional body or description submitted with the review request.

title: String

Title shown in the forge review-request UI.